==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/pt_BR.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendário",
    "%s has published the calendar \"%s\"" : "%s publicou o calendário \"%s\"",
    "Too many redirects. Aborting ..." : "Muitos redirecionamentos. Abortando...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "O servidor remoto não nos deu acesso ao calendário (erro HTTP {%s})",
    "Error connecting to remote server" : "Erro ao conectar o servidor remoto",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Erro ao solicitar recurso no servidor remoto. Isso poderia estar relacionado a uma incompatibilidade de certificado",
    "Error requesting resource on remote server" : "Erro ao solicitar recurso no servidor remoto",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Espaço",
    "Unknown" : "Desconhecido",
    "Required" : "Requerido",
    "Optional" : "Opcional",
    "Does not attend" : "Não atende",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Você está em um fuso horário desconhecido ({tz}), retornando para UTC",
    "Please create a calendar first." : "Por favor crie um calendário primeiro.",
    "New event" : "Novo evento",
    "CalDAV address for clients" : "Endereço CalDAV para clientes",
    "Error saving WebCal-calendar" : "Erro salvando o calendário WebCal",
    "WebDAV address for subscriptions" : "Endereço WebDAV para inscrições",
    "EMail has been sent." : "E-mail enviado",
    "There was an issue while sending your EMail." : "Houve um erro ao enviar o e-mail",
    "group" : "grupo",
    "Details" : "Detalhes",
    "Attendees" : "Participantes",
    "Reminders" : "Lembretes",
    "Repeating" : "Repetindo",
    "When shared show full event" : "Quando compartilhado mostrar evento completo",
    "When shared show only busy" : "Quando compartilhado mostrar apenas ocupado",
    "When shared hide this event" : "Quando compartilhado esconder este evento",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativa",
    "Cancelled" : "Cancelado",
    "Please add a title!" : "Por favor adicione um título!",
    "Please select a calendar!" : "Por favor, selecione um calendário",
    "The event ends before it starts!" : "O evento termina antes de começar!",
    "Global" : "Global",
    "None" : "Nenhum",
    "Every day" : "Todos os dias",
    "Every week" : "Toda semana",
    "Every month" : "Todo mês",
    "Every year" : "Todo ano",
    "never" : "nunca",
    "after" : "após",
    "How about getting started by importing some calendars?" : "Que tal começar importando alguns calendários?",
    "At time of event" : "No momento do evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personalizadas",
    "Audio" : "Áudio",
    "E Mail" : "E-mail",
    "Pop up" : "Pop-up",
    "sec" : "seg",
    "min" : "min",
    "hours" : "horas",
    "days" : "dias",
    "week" : "semana",
    "before" : "antes",
    "start" : "início",
    "end" : "fim",
    "Editing reminders of unknown type not supported." : "Edição de lembretes de tipos desconhecidos não são suportados.",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported" : "Importada",
    "Partially imported, 1 failure" : "Parcialmente importada, 1 falha",
    "Partially imported, {n} failures" : "Parcialmente importada, {n} falha",
    "Audio alarm" : "Alarme sonoro",
    "Pop-up" : "Pop-up",
    "E-Mail" : "E-mail",
    "{type} {time} before the event starts" : "{type} {time} antes do evento iniciar",
    "{type} {time} before the event ends" : "{type} {time} antes do evento terminar",
    "{type} {time} after the event starts" : "{type} {time} após o evento iniciar",
    "{type} {time} after the event ends" : "{type} {time} após o evento terminar",
    "{type} at the event's start" : "{type} no início do evento",
    "{type} at the event's end" : "{type} no final do evento",
    "{type} at {time}" : "{type} em {time}",
    "{calendar} shared by {owner}" : "{calendar} compartilhado por {owner}",
    "Please enter a valid WebCal-URL" : "Por favor entre uma URL válida para WEbCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Erro severo no proxy WebCal. Por favor contacte o administrador para mais informações.",
    "Title of the Event" : "Título do evento",
    "Starts" : "Inicia em",
    "Ends" : "Termina em",
    "All day Event" : "Evento todo o dia",
    "Delete" : "Excluir",
    "Cancel" : "Cancelar",
    "More ..." : "Mais...",
    "Create" : "Criar",
    "Update" : "Atualizar",
    "Close" : "Fechar",
    "Location" : "Localização",
    "Description" : "Descrição",
    "Event status" : "Status do evento",
    "Visibility when sharing" : "Visível quando compartilhando",
    "Export" : "Exportar",
    "%s has published the calendar %s" : "%s publicou o calendário%s",
    "Hello," : "Olá,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Gostaríamos de avisá-lo que %s publicou o calendário {boldstart}%s{boldend}",
    "Click here to access it" : "Clique aqui para acessar",
    "Cheers!" : "Saudações!",
    "We wanted to inform you that %s has published the calendar %s." : "Gostaríamos de avisá-lo que %s publicou o calendário %s.",
    "Click on the link below to access it" : "Clique no link abaixo para acessá-lo",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um bug, no momento o calendário é incapaz de fornecer suporte para o recurso de pipeline ativo.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor entre em contato com o administrador e solicite a desativação da opção de configuração \"asset-pipeline.enabled\".",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "Today" : "Hoje",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Alguns eventos neste calendário estão quebrados. Por favor, verifique o console JS para mais informações.",
    "Share Calendar" : "Compartilhar Calendário",
    "Shared" : "Compartilhado",
    "More" : "Mais",
    "Edit" : "Editar",
    "Link" : "Link",
    "iCal link" : "Link do iCal",
    "Download" : "Baixar",
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "can edit" : "pode editar",
    "Share link" : "Compartilhar link",
    "Public access" : "Acesso público",
    "Email link to person" : "Enviar link via e-mail para alguém",
    "Send" : "Enviar",
    "New Calendar" : "Novo Calendário",
    "Name" : "Nome",
    "New Subscription" : "Nova Subscrição",
    "Go back" : "Voltar",
    "Go forward" : "Avançar",
    "Calendar does not exist" : "O calendário não existe",
    "Maybe you got a wrong link or the calendar was unshared?" : "Será o link errado ou calendário descompartilhado?",
    "Edit event" : "Editar evento",
    "Delete Event" : "Excluir Evento",
    "Save Event" : "Salvar Evento",
    "Time" : "Horário",
    "Type" : "Digite",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "vezes a cada",
    "Add" : "Adicionar",
    "E-Mail address of attendee" : "Endereço de e-mail do participante",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione seu endereço de e-mail nas configurações pessoais, a fim de adicionar participantes.",
    "from" : "de",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "Esta regra de repetição de evento ainda não é suportada.",
    "Support for advanced rules will be added with subsequent updates." : "Suporte para regras avançadas serão adicionados em futuras atualizações.",
    "Reset repeating rule" : "Resetar a regra de repetição",
    "Repeat every ..." : "Repetir a cada...",
    "end repeat ..." : "fim da repetição...",
    "times" : "vezes",
    "Import Calendars" : "Importar Calendários",
    "Import canceled" : "Importação cancelada",
    "Analyzing calendar" : "Analisando calendário",
    "The file contains objects incompatible with the selected calendar" : "O arquivo contém objetos incompatíveis com o calendário selecionado",
    "New calendar" : "Novo calendário",
    "File is empty" : "Arquivo vazio",
    "Import scheduled" : "Importar agendados",
    "%s shared the calendar <strong>%s</strong> with you" : "%s compartilhou o calendário <strong>%s</strong> com você",
    "Embed" : "Embutido",
    "IFrame to integrate" : "IFrame a integrar",
    "Publish URL" : "Publicar URL",
    "Settings & import" : "Configurações & Importação",
    "Skip simple event editor" : "Pular editor de eventos simples",
    "Show week numbers" : "Mostrar o número das semanas",
    "Import calendar" : "Importar calendário",
    "No Calendars selected for import" : "Nenhum Calendário foi selecionado para importação",
    "Primary CalDAV address" : "Endereço CalDAV primário",
    "iOS/OS X CalDAV address" : "Endereço iOS/OS X CalDAV ",
    "Subscribe" : "Inscrever-se"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/pt_BR.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendário",
    "%s has published the calendar »%s«" : "%s publicou o calendário »%s«",
    "Hello," : "Olá,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Informamos que %s publicou o calendário »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "Saudações!",
    "Recipient" : "Destinatário",
    "Too many redirects. Aborting ..." : "Muitos redirecionamentos. Abortando...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "O servidor remoto não nos deu acesso ao calendário (erro HTTP {%s})",
    "Error connecting to remote server" : "Erro ao conectar o servidor remoto",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Erro ao solicitar recurso no servidor remoto. Isso poderia estar relacionado a uma incompatibilidade de certificado",
    "Error requesting resource on remote server" : "Erro ao solicitar recurso no servidor remoto",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Espaço",
    "Unknown" : "Desconhecido",
    "Required" : "Requerido",
    "Optional" : "Opcional",
    "Does not attend" : "Não atende",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Você está em um fuso horário desconhecido ({tz}), retornando para UTC",
    "Please create a calendar first." : "Por favor crie um calendário primeiro.",
    "New event" : "Novo evento",
    "CalDAV address for clients" : "Endereço CalDAV para clientes",
    "Error saving WebCal-calendar" : "Erro salvando o calendário WebCal",
    "WebDAV address for subscriptions" : "Endereço WebDAV para inscrições",
    "Email has been sent." : "O e-mail foi enviado.",
    "There was an issue while sending your email." : "Houve um problema ao enviar o e-mail.",
    "group" : "grupo",
    "Details" : "Detalhes",
    "Attendees" : "Participantes",
    "Reminders" : "Lembretes",
    "Repeating" : "Repetindo",
    "When shared show full event" : "Quando compartilhado mostrar evento completo",
    "When shared show only busy" : "Quando compartilhado mostrar apenas ocupado",
    "When shared hide this event" : "Quando compartilhado esconder este evento",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativa",
    "Cancelled" : "Cancelado",
    "Please add a title." : "Por favor, adicione um título.",
    "Please select a calendar." : "Por favor, selecione um calendário.",
    "The event can not end before it starts." : "O evento não pode terminar antes de começar.",
    "Global" : "Global",
    "None" : "Nenhum",
    "Every day" : "Todos os dias",
    "Every week" : "Todas as semanas",
    "Every month" : "Todo mês",
    "Every year" : "Todo ano",
    "never" : "nunca",
    "after" : "após",
    "How about getting started by importing some calendars?" : "Que tal começar importando alguns calendários?",
    "At time of event" : "No momento do evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personalizadas",
    "Audio" : "Áudio",
    "Email" : "E-mail",
    "Pop-up" : "Pop-up",
    "sec" : "seg",
    "min" : "min",
    "hours" : "horas",
    "days" : "dias",
    "week" : "semana",
    "before" : "antes",
    "start" : "início",
    "end" : "fim",
    "Editing reminders of unknown type not supported." : "Edição de lembretes de tipos desconhecidos não são suportados.",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported" : "Importada",
    "Partially imported, 1 failure" : "Parcialmente importada, 1 falha",
    "Partially imported, {n} failures" : "Parcialmente importada, {n} falha",
    "Audio alarm" : "Alarme sonoro",
    "{type} {time} before the event starts" : "{type} {time} antes do evento iniciar",
    "{type} {time} before the event ends" : "{type} {time} antes do evento terminar",
    "{type} {time} after the event starts" : "{type} {time} após o evento iniciar",
    "{type} {time} after the event ends" : "{type} {time} após o evento terminar",
    "{type} at the event's start" : "{type} no início do evento",
    "{type} at the event's end" : "{type} no final do evento",
    "{type} at {time}" : "{type} em {time}",
    "{calendar} shared by {owner}" : "{calendar} compartilhado por {owner}",
    "Please enter a valid WebCal-URL" : "Por favor entre uma URL válida para WEbCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Erro severo no proxy WebCal. Por favor contacte o administrador para mais informações.",
    "Title of the Event" : "Título do evento",
    "Starts" : "Inicia em",
    "Ends" : "Termina em",
    "All day Event" : "Evento todo o dia",
    "Delete" : "Excluir",
    "Cancel" : "Cancelar",
    "More ..." : "Mais...",
    "Create" : "Criar",
    "Update" : "Atualizar",
    "Close" : "Fechar",
    "Location" : "Localização",
    "Description" : "Descrição",
    "Event status" : "Status do evento",
    "Visibility when sharing" : "Visível quando compartilhando",
    "Export" : "Exportar",
    "%s has published the calendar %s" : "%s publicou o calendário%s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Gostaríamos de avisá-lo que %s publicou o calendário {boldstart}%s{boldend}",
    "Click here to access it" : "Clique aqui para acessar",
    "We wanted to inform you that %s has published the calendar %s." : "Gostaríamos de avisá-lo que %s publicou o calendário %s.",
    "Click on the link below to access it" : "Clique no link abaixo para acessá-lo",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "Today" : "Hoje",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Alguns eventos neste calendário estão corrompidos. Por favor, verifique o console JS para mais informações.",
    "Share Calendar" : "Compartilhar Calendário",
    "Shared" : "Compartilhado",
    "More" : "Mais",
    "Edit" : "Editar",
    "Link" : "Link",
    "iCal link" : "Link do iCal",
    "Download" : "Baixar",
    "Share with users or groups" : "Compartilhar com usuários ou grupos",
    "can edit" : "pode editar",
    "Share link" : "Compartilhar link",
    "Public access" : "Acesso público",
    "Email link to person" : "Enviar link via e-mail para alguém",
    "Send" : "Enviar",
    "New Calendar" : "Novo Calendário",
    "Name" : "Nome",
    "New Subscription" : "Nova Subscrição",
    "Go back" : "Voltar",
    "Go forward" : "Avançar",
    "Calendar does not exist" : "O calendário não existe",
    "Maybe you got a wrong link or the calendar was unshared?" : "Será o link errado ou calendário descompartilhado?",
    "Edit event" : "Editar evento",
    "Delete Event" : "Excluir Evento",
    "Save Event" : "Salvar Evento",
    "Time" : "Horário",
    "Type" : "Digite",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "vezes a cada",
    "Add" : "Adicionar",
    "Email address of attendee" : "Endereço de e-mail do atendente",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione seu endereço de e-mail nas configurações pessoais, a fim de adicionar participantes.",
    "from" : "de",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "Esta regra de repetição de evento ainda não é suportada.",
    "Support for advanced rules will be added with subsequent updates." : "Suporte para regras avançadas serão adicionados em futuras atualizações.",
    "Reset repeating rule" : "Resetar a regra de repetição",
    "Repeat every ..." : "Repetir a cada...",
    "end repeat ..." : "fim da repetição...",
    "times" : "vezes",
    "Import Calendars" : "Importar Calendários",
    "Import canceled" : "Importação cancelada",
    "Analyzing calendar" : "Analisando calendário",
    "The file contains objects incompatible with the selected calendar" : "O arquivo contém objetos incompatíveis com o calendário selecionado",
    "New calendar" : "Novo calendário",
    "File is empty" : "Arquivo vazio",
    "Import scheduled" : "Importar agendados",
    "%s shared the calendar <strong>%s</strong> with you" : "%s compartilhou o calendário <strong>%s</strong> com você",
    "Embed" : "Incorporar",
    "Iframe to integrate" : "Iframe a integrar",
    "Publish URL" : "Publicar URL",
    "Settings & import" : "Configurações & Importação",
    "Skip simple event editor" : "Saltar editor de eventos simples",
    "Show week numbers" : "Mostrar o número das semanas",
    "Import calendar" : "Importar calendário",
    "No Calendars selected for import" : "Nenhum Calendário foi selecionado para importação",
    "Primary CalDAV address" : "Endereço CalDAV primário",
    "iOS/OS X CalDAV address" : "Endereço iOS/OS X CalDAV ",
    "Subscribe" : "Inscrever-se"
},
"nplurals=2; plural=(n > 1);");
